pept.scanners.modular_camera.extensions API documentation

# Module `pept.scanners.modular_camera.extensions`

Source code

    #!/usr/bin/env python3
    # -*- coding: utf-8 -*-

    # File   : __init__.py
    # License: License: GNU v3.0
    # Author : Sam Manger <s.manger@bham.ac.uk>
    # Date   : 25.08.2019

    from    .   import  get_pept_event

    __all__ = [
        'get_pept_event'
    ]

    __author__ =        "Sam Manger"
    __credits__ =       ["Andrei Leonard Nicusan", "Kit Windows-Yule", "Sam Manger"]
    __license__ =       "GNU v3.0"
    __version__ =       "0.1.0"
    __maintainer__ =    "Sam Manger"
    __email__ =         "s.manger@bham.ac.uk"
    __status__ =        "Development"